meta-quanta: gbs: Change the BIOS main flash label to bios-primary

Change the BIOS main flash label to 'bios-primary' from 'pnor'
for the bios-update.sh

ref: https://github.com/openbmc/linux/commit/2eea476

Signed-off-by: GeorgeHuang <george.hung@quantatw.com>
Change-Id: I208a24cd5f7956cc3461986eb0aed0348c186ebf
diff --git a/meta-quanta/meta-gbs/recipes-gbs/gbs-bios-update/files/bios-update.sh b/meta-quanta/meta-gbs/recipes-gbs/gbs-bios-update/files/bios-update.sh
index 36dfa45..bf71e94 100644
--- a/meta-quanta/meta-gbs/recipes-gbs/gbs-bios-update/files/bios-update.sh
+++ b/meta-quanta/meta-gbs/recipes-gbs/gbs-bios-update/files/bios-update.sh
@@ -75,14 +75,14 @@
     fi
     echo "${KERNEL_FIU_ID}" > "${KERNEL_SYSFS_FIU}"/bind
 
-    # BIOS flash is labelled 'pnor'
-    pnor_mtd=$(findmtd pnor)
-    if [ -z "${pnor_mtd}" ]; then
+    # BIOS flash is labelled 'bios-primary'
+    bios_mtd=$(findmtd bios-primary)
+    if [ -z "${bios_mtd}" ]; then
         echo "Cannot find bios flash mtd partition!"
         exit 1
     fi
 
-    flashcp -v $IMAGE_FILE /dev/"${pnor_mtd}"
+    flashcp -v $IMAGE_FILE /dev/"${bios_mtd}"
     if [ $? -eq 0 ]; then
         echo "bios update successfully..."
     else